@@ -12,6 +12,7 @@ use nix::errno::Errno;
 use crate::{
     hook::{SysArg, UNotifyEventRequest},
     kernel::syscall_path_handler,
+    warn,
 };
 
 pub(crate) fn sys_chroot(request: UNotifyEventRequest) -> ScmpNotifResp {
@@ -21,16 +22,14 @@ pub(crate) fn sys_chroot(request: UNotifyEventRequest) -> ScmpNotifResp {
     }];
 
     syscall_path_handler(request, "chroot", argv, |path_args, request, sandbox| {
+        let is_chroot = sandbox.is_chroot();
         drop(sandbox); // release the read lock.
 
         // SAFETY: SysArg has one element.
         #[expect(clippy::disallowed_methods)]
         let path = path_args.0.as_ref().unwrap();
 
-        if path.abs().is_rootfs() {
-            // chroot("/") is a no-op.
-            return Ok(request.return_syscall(0));
-        } else if let Some(typ) = path.typ.as_ref() {
+        if let Some(typ) = path.typ.as_ref() {
             if !typ.is_dir() {
                 return Ok(request.fail_syscall(Errno::ENOTDIR));
             }
@@ -38,11 +37,30 @@ pub(crate) fn sys_chroot(request: UNotifyEventRequest) -> ScmpNotifResp {
             return Ok(request.fail_syscall(Errno::ENOENT));
         }
 
+        // SAFETY: Do not allow nested chroots.
+        if is_chroot {
+            return Ok(request.fail_syscall(Errno::EACCES));
+        }
+
         // Acquire a write lock and chroot the sandbox.
         let mut sandbox = request.get_mut_sandbox();
         sandbox.chroot();
+        let verbose = sandbox.verbose;
         drop(sandbox); // release the write-lock.
 
+        if verbose {
+            warn!("ctx": "chroot_sandbox",
+                "sys": "chroot", "path": &path,
+                "msg": "change root approved",
+                "req": request);
+        } else {
+            warn!("ctx": "chroot_sandbox",
+                "sys": "chroot", "path": &path,
+                "msg": "change root approved",
+                "pid": request.scmpreq.pid);
+        }
+
+        // Return success to the caller.
         Ok(request.return_syscall(0))
     })
 }
