@@ -997,8 +997,8 @@ syd::main! {
     }
 
     // Disable Speculative Store Bypass mitigations
-    // for trace/allow_unsafe_spec_exec:1
-    let ssb = sandbox.flags.allow_unsafe_spec_exec();
+    // for trace/allow_unsafe_exec_speculative:1
+    let ssb = sandbox.flags.allow_unsafe_exec_speculative();
 
     // SAFETY: fork is our safest option here.
     let child = match unsafe { fork() }? {
@@ -1062,7 +1062,7 @@ syd::main! {
     ctx.set_ctl_nnp(true)?;
 
     // Disable Speculative Store Bypass mitigations
-    // with trace/allow_unsafe_spec_exec:1
+    // with trace/allow_unsafe_exec_speculative:1
     ctx.set_ctl_ssb(ssb)?;
 
     // DO NOT synchronize filter to all threads.
